tlslite.messages.ServerKeyExchange

Package tlslite :: Module messages :: Class ServerKeyExchange |
[show private | hide private]
[frames | no frames]

## Class ServerKeyExchange

         Msg --+
               |
    HandshakeMsg --+
                   |
                  ServerKeyExchange

Method Summary
| `__init__(self, cipherSuite)`
| `createSRP(self, srp_N, srp_g, srp_s, srp_B)`
| `hash(self, clientRandom, serverRandom)`
| `parse(self, p)`
| `write(self, trial)`
Inherited from HandshakeMsg
| ``preWrite`(self, handshakeType, trial)`
Inherited from Msg
| ``postWrite`(self, w, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net